@@ -3,7 +3,7 @@
                              -------------------
     begin                : Feb 04 2004
     copyright            : (C) 2004 by Franck Babin
-                           (C) 2005 by Alexander Reinholdt
+                           (C) 2005-2007 by Alexander Reinholdt
     email                : babinfranck@yahoo.ca
                            dustpuppy@mail.berlios.de
  ***************************************************************************/
@@ -25,54 +25,35 @@
  *   MA  02111-1307 USA                                                    *
  ***************************************************************************/
 
- //Application includes
-#include "smb4kbookmark.h"
+// KDE includes
+#include <ksocketaddress.h>
 
-Smb4KBookmark::Smb4KBookmark( const QString &host, const QString &share, const QString &workgroup, const QString &ip, const QString &type )
-: m_host( host ), m_share( share ), m_workgroup( workgroup ), m_ip( ip ), m_type( type )
+// application specific includes
+#include "smb4kbookmark.h"
+#include "smb4knetworkitems.h"
+
+
+Smb4KBookmark::Smb4KBookmark( const QString &host, const QString &share, const QString &workgroup, const QString &ip, const QString &type, const QString &label )
+: m_host( host ), m_share( share ), m_workgroup( workgroup ), m_type( type ), m_label( label )
 {
     //FIXME should throw an exception if one of the param is empty
 
+  m_ip = ipIsValid( ip ) ? ip : QString::null;
   m_bookmark = QString( "//%1/%2" ).arg( m_host, m_share );
 }
 
-Smb4KBookmark::~Smb4KBookmark(){}
 
-
-
-const QString &Smb4KBookmark::share()
+Smb4KBookmark::Smb4KBookmark( Smb4KShareItem *item, const QString &ip, const QString &label )
+: m_host( item->host() ), m_share( item->name() ), m_workgroup( item->workgroup() ),
+  m_type( item->plainType() ), m_label( label )
 {
-  return m_share;
+  m_ip = ipIsValid( ip ) ? ip : QString::null;
+  m_bookmark = QString( "//%1/%2" ).arg( m_host, m_share );
 }
 
 
-const QString &Smb4KBookmark::type()
+Smb4KBookmark::~Smb4KBookmark()
 {
-  return m_type;
-}
-
-
-const QString &Smb4KBookmark::workgroup()
-{
-  return m_workgroup;
-}
-
-
-const QString &Smb4KBookmark::ip()
-{
-  return m_ip;
-}
-
-
-const QString &Smb4KBookmark::bookmark()
-{
-  return m_bookmark;
-}
-
-
-const QString &Smb4KBookmark::host()
-{
-  return m_host;
 }
 
 
@@ -86,5 +67,31 @@ void Smb4KBookmark::setShareName( const QString &name )
 
 void Smb4KBookmark::setIP( const QString &ip )
 {
-  m_ip = ip;
+  m_ip = ipIsValid( ip ) ? ip : QString::null;
+}
+
+
+void Smb4KBookmark::setLabel( const QString &text )
+{
+  m_label = text;
+}
+
+
+bool Smb4KBookmark::ipIsValid( const QString &ip )
+{
+  if ( !ip.isEmpty() )
+  {
+    KNetwork::KIpAddress ip_address = KNetwork::KIpAddress( ip );
+
+    if ( !ip_address.isIPv4Addr() && !ip_address.isIPv6Addr() )
+    {
+      return false;
+    }
+  }
+  else
+  {
+    return false;
+  }
+
+  return true;
 }
