@@ -32,11 +32,18 @@
 #include <kdebug.h>
 #include <kapplication.h>
 
+// system specific includes
+#include <stdlib.h>
+#include <math.h>
+
 // application specific includes
 #include "smb4kbookmarkhandler.h"
 #include "smb4kdefs.h"
 #include "smb4kerror.h"
 #include "smb4kglobal.h"
+#include "smb4knetworkitems.h"
+#include "smb4kbookmark.h"
+
 using namespace Smb4KGlobal;
 
 
@@ -73,12 +80,14 @@ Smb4KBookmarkHandler::~Smb4KBookmarkHandler()
 }
 
 
-/****************************************************************************
-   Writes the bookmark to the bookmark file, too.
-****************************************************************************/
 
 void Smb4KBookmarkHandler::addBookmark( Smb4KBookmark *bookmark )
 {
+  if ( !bookmark )
+  {
+    return;
+  }
+
   if ( QString::compare( bookmark->type(), "Printer" ) == 0 )
   {
     Smb4KError::error( ERROR_BOOKMARK_PRINTER );
@@ -92,36 +101,35 @@ void Smb4KBookmarkHandler::addBookmark( Smb4KBookmark *bookmark )
     bookmark->setShareName( share );
   }
 
-  for ( QValueList<Smb4KBookmark *>::Iterator it = m_bookmarks.begin(); it != m_bookmarks.end(); ++it )
+  // Search for the bookmark:
+  Smb4KBookmark *result = findBookmarkByName( bookmark->bookmark() );
+
+  if ( result )
   {
-    if ( QString::compare( (*it)->bookmark().lower(), bookmark->bookmark().lower() ) == 0 &&
-         QString::compare( (*it)->workgroup().lower(), bookmark->workgroup().lower() ) == 0 &&
-         QString::compare( (*it)->ip(), bookmark->ip() ) == 0 )
+    if ( QString::compare( result->workgroup().upper(), bookmark->workgroup().upper() ) == 0 )
     {
-      // already exists
-      return;
-    }
-    else if ( QString::compare( (*it)->bookmark().lower(), bookmark->bookmark().lower() ) == 0 &&
-              (QString::compare( (*it)->workgroup().lower(), bookmark->workgroup().lower() ) != 0 ||
-               QString::compare( (*it)->ip(), bookmark->ip() ) != 0) )
-    {
-      // remove obsolete bookmark entry
-      delete *it;
-      *it = NULL;
+      // It's the same bookmark. We'll update it in a very
+      // brutal but efficient way:
+      m_bookmarks.remove( result );
+
+      if ( result )
+      {
+        delete result;
+      }
     }
+
+    m_bookmarks.append( bookmark );
+  }
+  else
+  {
+    // The bookmark is new. Append it to the list:
+    m_bookmarks.append( bookmark );
   }
 
-  m_bookmarks.remove( NULL );
-
-  m_bookmarks.append( bookmark );
   writeBookmarkList( m_bookmarks );
 }
 
 
-/****************************************************************************
-   Writes a new list of bookmarks to the bookmark file.
-****************************************************************************/
-
 void Smb4KBookmarkHandler::writeBookmarkList( const QValueList<Smb4KBookmark *> &list )
 {
   if ( list != m_bookmarks )
@@ -143,9 +151,29 @@ void Smb4KBookmarkHandler::writeBookmarkList( const QValueList<Smb4KBookmark *>
     QTextStream ts( &file );
     ts.setEncoding( QTextStream::Locale );
 
+    int serial_number = 0;
+
     for ( QValueListConstIterator<Smb4KBookmark *> it = m_bookmarks.begin(); it != m_bookmarks.end(); ++it )
     {
-      ts << (*it)->host() << "," << (*it)->share() << "," << (*it)->workgroup() << "," << (*it)->ip() << endl;
+      if ( !(*it)->label().isEmpty() )
+      {
+        Smb4KBookmark *result = findBookmarkByLabel( (*it)->label() );
+
+        if ( result &&
+             (QString::compare( result->bookmark().upper(), (*it)->bookmark().upper() ) != 0 ||
+             QString::compare( result->workgroup().upper(), (*it)->workgroup().upper() ) != 0) )
+        {
+          Smb4KError::information( INFO_BOOKMARK_LABEL_IN_USE, (*it)->label(), (*it)->bookmark() );
+
+          (*it)->setLabel( QString( "%1 (%2)" ).arg( (*it)->label() ).arg( serial_number++ ) );
+        }
+      }
+
+      ts << (*it)->host() << ","
+         << (*it)->share() << ","
+         << (*it)->workgroup() << ","
+         << (*it)->ip() << ","
+         << (*it)->label() << endl;
     }
 
     file.close();
@@ -160,10 +188,6 @@ void Smb4KBookmarkHandler::writeBookmarkList( const QValueList<Smb4KBookmark *>
 }
 
 
-/****************************************************************************
-   Load the bookmarks.
-****************************************************************************/
-
 void Smb4KBookmarkHandler::loadBookmarks()
 {
   QFile file( locateLocal( "data", "smb4k/bookmarks", KGlobal::instance() ) );
@@ -200,8 +224,9 @@ void Smb4KBookmarkHandler::loadBookmarks()
           QString share = (*it).section( ",", 1, 1 ).stripWhiteSpace();
           QString workgroup = (*it).section( ",", 2, 2 ).stripWhiteSpace();
           QString ip = (*it).section( ",", 3, 3 ).stripWhiteSpace();
+          QString label = (*it).section( ",", 4, 4 ).stripWhiteSpace();
 
-          m_bookmarks.append( new Smb4KBookmark( host, share, workgroup, ip, "Disk" ) );
+          m_bookmarks.append( new Smb4KBookmark( host, share, workgroup, ip, "Disk", label ) );
         }
       }
     }
@@ -222,11 +247,7 @@ void Smb4KBookmarkHandler::loadBookmarks()
 }
 
 
-/****************************************************************************
-   Return a bookmark object from the list
-****************************************************************************/
-
-Smb4KBookmark *Smb4KBookmarkHandler::findBookmark( const QString &bookmark )
+Smb4KBookmark *Smb4KBookmarkHandler::findBookmarkByName( const QString &bookmark )
 {
   // Update the bookmarks:
   update();
@@ -236,7 +257,7 @@ Smb4KBookmark *Smb4KBookmarkHandler::findBookmark( const QString &bookmark )
 
   for ( it = m_bookmarks.begin(); it != m_bookmarks.end(); ++it )
   {
-    if ( QString::compare( (*it)->bookmark().lower(), bookmark.lower() ) == 0 )
+    if ( QString::compare( (*it)->bookmark().upper(), bookmark.upper() ) == 0 )
     {
       break;
     }
@@ -246,9 +267,25 @@ Smb4KBookmark *Smb4KBookmarkHandler::findBookmark( const QString &bookmark )
 }
 
 
-/****************************************************************************
-   Return the list of bookmarks
-****************************************************************************/
+Smb4KBookmark *Smb4KBookmarkHandler::findBookmarkByLabel( const QString &label )
+{
+  // Update the bookmarks:
+  update();
+
+  // Find the bookmark:
+  QValueListConstIterator<Smb4KBookmark *> it;
+
+  for ( it = m_bookmarks.begin(); it != m_bookmarks.end(); ++it )
+  {
+    if ( QString::compare( (*it)->label().upper(), label.upper() ) == 0 )
+    {
+      break;
+    }
+  }
+
+  return it != m_bookmarks.end() ? *it : NULL;
+}
+
 
 const QValueList<Smb4KBookmark *> &Smb4KBookmarkHandler::getBookmarks()
 {
@@ -260,11 +297,6 @@ const QValueList<Smb4KBookmark *> &Smb4KBookmarkHandler::getBookmarks()
 }
 
 
-
-/****************************************************************************
-   Update the bookmarks.
-****************************************************************************/
-
 void Smb4KBookmarkHandler::update()
 {
   // If the user didn't pass the global Smb4KHostItem list, we are not able
@@ -282,7 +314,6 @@ void Smb4KBookmarkHandler::update()
       if ( QString::compare( (*it)->workgroup().lower(), (*i)->workgroup().lower() ) != 0 )
       {
         // Continue, if the workgroup is not the same:
-
         continue;
       }
       else
@@ -290,7 +321,6 @@ void Smb4KBookmarkHandler::update()
         if ( QString::compare( (*it)->host().lower(), (*i)->name().lower() ) != 0 )
         {
           // Continue if the host name is not the same:
-
           continue;
         }
         else
