@@ -43,7 +43,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The browse list could not be retrieved.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The browse list could not be retrieved.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -56,7 +56,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The list of servers could not be retrieved.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The list of servers could not be retrieved.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -69,7 +69,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The list of shares could not be retrieved.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The list of shares could not be retrieved.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -82,14 +82,14 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The preview could not be compiled.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The preview could not be compiled.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
     }
     case ERROR_OPENING_WALLET_FAILED:
     {
-      KMessageBox::error( 0, i18n( "The wallet '%1' could not be opened. KWallet support will be disabled." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The wallet \"%1\" could not be opened. KWallet support will be disabled." ).arg( text ) );
 
       break;
     }
@@ -101,7 +101,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "Some file permissions could not be determined.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "Some file permissions could not be determined.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -116,11 +116,11 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
     {
       if ( details.stripWhiteSpace().isEmpty() )
       {
-        KMessageBox::error( 0, i18n( "The share '%1' could not be mounted.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
+        KMessageBox::error( 0, i18n( "The share \"%1\" could not be mounted.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The share '%1' could not be mounted.\nRead the error message under 'Details' to find out more." ).arg( text ), details );
+        KMessageBox::detailedError( 0, i18n( "The share \"%1\" could not be mounted.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
       }
 
       break;
@@ -129,24 +129,31 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
     {
       if ( details.stripWhiteSpace().isEmpty() )
       {
-        KMessageBox::error( 0, i18n( "The share '%1' could not be unmounted.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
+        KMessageBox::error( 0, i18n( "The share \"%1\" could not be unmounted.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The share '%1' could not be unmounted.\nRead the error message under 'Details' to find out more." ).arg( text ), details );
+        KMessageBox::detailedError( 0, i18n( "The share \"%1\" could not be unmounted.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
       }
 
       break;
     }
     case ERROR_FILE_NOT_FOUND:
     {
-      KMessageBox::error( 0, i18n( "The file '%1' could not be found." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The file \"%1\" could not be found." ).arg( text ) );
 
       break;
     }
     case ERROR_READING_FILE:
     {
-      KMessageBox::error( 0, i18n( "The file '%1' could not be read." ).arg( text ) );
+      if ( details.stripWhiteSpace().isEmpty() )
+      {
+        KMessageBox::error( 0, i18n( "The file \"%1\" could not be read." ).arg( text ) );
+      }
+      else
+      {
+        KMessageBox::detailedError( 0, i18n( "The file \"%1\" could not be read.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
+      }
 
       break;
     }
@@ -158,7 +165,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The name of your computer could not be determined by using the gethostname() system call.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The name of your computer could not be determined by using the gethostname() system call.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -171,44 +178,25 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
     }
     case ERROR_LOCKED:
     {
-      KMessageBox::error( 0, i18n( "The file '%1' is currently being edited by user %2. To avoid any problems, access to this file is denied at the moment. Please try again later." ).arg( text.section( ":", 1, 1 ), text.section( ":", 0, 0 ) ) );
+      KMessageBox::error( 0, i18n( "The file \"%1\" is currently being edited by user %2. To avoid any problems, access to this file is denied at the moment. Please try again later." ).arg( text.section( ":", 1, 1 ), text.section( ":", 0, 0 ) ) );
 
       break;
     }
     case ERROR_MKDIR_FAILED:
     {
-      KMessageBox::error( 0, i18n( "The directory '%1' could not be created." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The directory \"%1\" could not be created." ).arg( text ) );
 
       break;
     }
     case ERROR_WRITING_FILE:
     {
-      KMessageBox::error( 0, i18n( "The file '%1' could not be written." ).arg( text ) );
-
-      break;
-    }
-    case ERROR_GETTING_USAGE:
-    {
-      if ( details.stripWhiteSpace().isEmpty() )
-      {
-        KMessageBox::error( 0, i18n( "The disk usage could not be determined.\nDetailed information cannot be provided because there was no error message." ) );
-      }
-      else
-      {
-        KMessageBox::detailedError( 0, i18n( "The disk usage could not be determined.\nRead the error message under 'Details' to find out more." ), details );
-      }
+      KMessageBox::error( 0, i18n( "The file \"%1\" could not be written." ).arg( text ) );
 
       break;
     }
     case ERROR_MOUNTPOINT_EMPTY:
     {
-      KMessageBox::error( 0, i18n( "The share could not be unmounted, because the mountpoint string was empty." ) );
-
-      break;
-    }
-    case ERROR_WRONG_KERNEL:
-    {
-      KMessageBox::error( 0, i18n( "The kernel (%1) does not support this operation." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The share could not be unmounted, because the mount point string was empty." ) );
 
       break;
     }
@@ -238,14 +226,14 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The list of mounted SMBFS and CIFS shares could not be imported.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The list of mounted SMBFS and CIFS shares could not be imported.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
     }
     case ERROR_COMMAND_NOT_FOUND:
     {
-      KMessageBox::error( 0, i18n( "The command '%1' could not be found." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The command \"%1\" could not be found." ).arg( text ) );
 
       break;
     }
@@ -253,11 +241,11 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
     {
       if ( details.stripWhiteSpace().isEmpty() )
       {
-        KMessageBox::error( 0, i18n( "The file '%1' could not be printed.\nDetailed information cannot be provided because there was no error message." ) );
+        KMessageBox::error( 0, i18n( "The file \"%1\" could not be printed.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The file '%1' could not be printed.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The file \"%1\" could not be printed.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
       }
 
       break;
@@ -266,11 +254,11 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
     {
       if ( details.stripWhiteSpace().isEmpty() )
       {
-        KMessageBox::error( 0, i18n( "The temporary directory '%1' could not be created.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
+        KMessageBox::error( 0, i18n( "The temporary directory \"%1\" could not be created.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The temporary directory '%1' could not be created.\nRead the error message under 'Details' to find out more." ).arg( text ), details );
+        KMessageBox::detailedError( 0, i18n( "The temporary directory \"%1\" could not be created.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
       }
 
       break;
@@ -279,24 +267,24 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
     {
       if ( details.stripWhiteSpace().isEmpty() )
       {
-        KMessageBox::error( 0, i18n( "The temporary file '%1' could not be created.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
+        KMessageBox::error( 0, i18n( "The temporary file \"%1\" could not be created.\nDetailed information cannot be provided because there was no error message." ).arg( text ) );
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The temporary file '%1' could not be created.\nRead the error message under 'Details' to find out more." ).arg( text ), details );
+        KMessageBox::detailedError( 0, i18n( "The temporary file \"%1\" could not be created.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
       }
 
       break;
     }
     case ERROR_DIRECTORY_NOT_FOUND:
     {
-      KMessageBox::error( 0, i18n( "The directory '%1' could not be found." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The directory \"%1\" could not be found." ).arg( text ) );
 
       break;
     }
-    case ERROR_LOCK_FILE_IS_SYMLINK:
+    case ERROR_FILE_IS_IRREGULAR:
     {
-      KMessageBox::error( 0, i18n( "The lock file '%1' is a symbolic link.\nIt looks like someone is trying to exploit your system. Please inform your system administrator. Smb4K will not perform any action on a system file as long as this problem is not solved." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The file \"%1\" is irregular. That means it is either a symlink, a fifo, or something similar. This could indicate that someone is trying to exploit your system. Please inform your system administrator." ).arg( text ) );
 
       break;
     }
@@ -308,7 +296,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The synchronization could not the accomplished successfully.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The synchronization could not the accomplished successfully.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -317,24 +305,31 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
     {
       if ( details.stripWhiteSpace().isEmpty() )
       {
-        KMessageBox::error( 0, i18n( "The file '%1' could not be opened." ).arg( text ) );
+        KMessageBox::error( 0, i18n( "The file \"%1\" could not be opened." ).arg( text ) );
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The file '%1' could not be opened.\nRead the error message under 'Details' to find out more." ).arg( text ), details );
+        KMessageBox::detailedError( 0, i18n( "The file \"%1\" could not be opened.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
+      }
+
+      break;
+    }
+    case ERROR_CLOSING_FILE:
+    {
+      if ( details.stripWhiteSpace().isEmpty() )
+      {
+        KMessageBox::error( 0, i18n( "The file \"%1\" could not be closed." ).arg( text ) );
+      }
+      else
+      {
+        KMessageBox::detailedError( 0, i18n( "The file \"%1\" could not be closed.\nRead the error message under \"Details\" to find out more." ).arg( text ), details );
       }
 
       break;
     }
     case ERROR_NET_COMMAND:
     {
-      KMessageBox::error( 0, i18n( "The list of arguments for the 'net' command could not be assembled.\nAt the moment it reads: %1" ).arg( text ) );
-
-      break;
-    }
-    case ERROR_PROGRAM_MISSING:
-    {
-      KMessageBox::error( 0, i18n( "The program '%1' could not be found." ).arg( text ) );
+      KMessageBox::error( 0, i18n( "The list of arguments for the \"net\" command could not be assembled.\nAt the moment it reads: %1" ).arg( text ) );
 
       break;
     }
@@ -346,7 +341,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "The list of supplementary group IDs could not be determined.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "The list of supplementary group IDs could not be determined.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -360,7 +355,7 @@ void Smb4KError::error( int code, const QString &text, const QString &details )
       }
       else
       {
-        KMessageBox::detailedError( 0, i18n( "An unknown error occurred.\nRead the error message under 'Details' to find out more." ), details );
+        KMessageBox::detailedError( 0, i18n( "An unknown error occurred.\nRead the error message under \"Details\" to find out more." ), details );
       }
 
       break;
@@ -381,19 +376,25 @@ int Smb4KError::warning( int code, const QString &, const QString & )
 }
 
 
-void Smb4KError::information( int code, const QString &text, const QString & )
+void Smb4KError::information( int code, const QString &text, const QString &details )
 {
   switch ( code )
   {
     case INFO_MIMETYPE_NOT_SUPPORTED:
     {
-      KMessageBox::information( 0, i18n( "The mimetype '%1' is not supported. Please convert the file to PostScript or PDF." ).arg( text ) );
+      KMessageBox::information( 0, i18n( "The mimetype \"%1\" is not supported. Please convert the file to PostScript or PDF." ).arg( text ) );
 
       break;
     }
     case INFO_DISABLE_SUID_FEATURE:
     {
-      KMessageBox::information( 0, i18n( "You previously chose to use '%1', but now it is missing on your system. Smb4K will disable this feature." ).arg( text ) );
+      KMessageBox::information( 0, i18n( "You previously chose to use \"%1\", but now it is missing on your system. Smb4K will disable this feature." ).arg( text ) );
+
+      break;
+    }
+    case INFO_BOOKMARK_LABEL_IN_USE:
+    {
+      KMessageBox::information( 0, i18n( "The label \"%1\" is used more than once. It will automatically be renamed for bookmark \"%2\" to avoid confusion." ).arg( text, details ) );
 
       break;
     }
