@@ -2,8 +2,8 @@
     smb4kmounter.h  -  The core class that mounts the shares.
                              -------------------
     begin                : Die Jun 10 2003
-    copyright            : (C) 2003 by Alexander Reinholdt
-    email                : dustpuppy@mail.berlios.de
+    copyright            : (C) 2003-2007 by Alexander Reinholdt
+    email                : dustpuppy@users.berlios.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -40,12 +40,20 @@
 #include <kprocess.h>
 
 // application specific includes
-#include "smb4kshare.h"
 #include "smb4kdefs.h"
 
+// forward declarations
+class Smb4KMounterPrivate;
+class Smb4KShare;
+
 
 /**
- * This is a core class. It mounts the shares.
+ * This is one of the core classes of Smb4K. It manages the mounting
+ * and unmounting of remote Samba/Windows shares. Additionally it maintains a
+ * list of all mounts with SMBFS and CIFS file system that are present
+ * on the system.
+ *
+ * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
 class Smb4KMounter : public QObject
@@ -71,7 +79,7 @@ class Smb4KMounter : public QObject
      * Enumeration for the state of the process. The members are also
      * used in the results() signal as return values.
      */
-    enum State{ MountRecent, Import, Mount, Unmount, UnmountAll, Idle };
+    enum State{ Remount, Import, Mount, Unmount, UnmountAll, Idle };
 
     /**
      * Unmounts a share. This can either be done the "normal" way, or you may
@@ -117,18 +125,27 @@ class Smb4KMounter : public QObject
     Smb4KShare* findShareByPath( const QString &path );
 
     /**
-     * Find a share in the list with its name
+     * Find all mounts of the particular share @p share on the system.
+     *
+     * @param name        The name of the share
+     *
+     * @returns the complete list of mounts of @p share.
      */
-    Smb4KShare* findShareByName( const QString &name );
+    QValueList<Smb4KShare> findShareByName( const QString &name );
 
     /**
      * This function returns TRUE if a share is mounted and FALSE otherwise.
      *
-     * @param name The name of the share. It has to look like this: //HOST/SHARE.
+     * @param name        The name of the share. It has to look like this:
+     *                    //HOST/SHARE.
+     *
+     * @param userOnly    Specifies whether this function should only consider
+     *                    shares mounted by the user or all shares that are
+     *                    available on the system. The default is TRUE.
      *
      * @return TRUE if the share is mounted and FALSE otherwise.
      */
-    bool isMounted( const QString &name );
+    bool isMounted( const QString &name, bool userOnly = true );
 
     /**
      * This function reports if the mounter is running or not.
@@ -152,6 +169,12 @@ class Smb4KMounter : public QObject
      */
     void prepareForShutdown();
 
+    /**
+     * This function initializes import of mounted shares and the remounting of recently
+     * used shares.
+     */
+    void init();
+
   signals:
     /**
      * This signal emits the run state.
@@ -167,19 +190,20 @@ class Smb4KMounter : public QObject
     void updated();
 
     /**
-     * This signal is emitted if a share has successfully been mounted. It is
-     * not used by the main program, but may be used by plugins, etc.
+     * This signal is emitted when a share has successfully been mounted or
+     * if it has already been mounted.
      *
      * @param mountpoint      The mount point of the share.
      */
     void mountedShare( const QString &mountpoint );
 
     /**
-     * This signal is emitted if the share is already mounted.
+     * This signal is emitted just before a share is unmounted.
      *
-     * @param mountpoint      The mount point of the already mounted share.
+     * @param mountpoint       The mount point of the share that is going to
+     *                         be unmounted.
      */
-    void alreadyMountedShare( const QString &mountpoint );
+    void aboutToUnmount( const QString &mountpoint );
 
   protected:
     /**
@@ -222,7 +246,7 @@ class Smb4KMounter : public QObject
     /**
      * Initiates the processing of the queue.
      */
-    void init();
+    void slotProcessQueue();
 
     /**
      * This slot is called by the KApplication::shutDown() signal.
@@ -233,9 +257,9 @@ class Smb4KMounter : public QObject
 
   private:
     /**
-     * Mount recently used shares.
+     * Remount shares that were used in the last session.
      */
-    void mountRecent();
+    void remount();
 
     /**
      * Imports mounted shares.
@@ -257,6 +281,15 @@ class Smb4KMounter : public QObject
      */
     void unmountAll();
 
+    /**
+     * Checks if the share @p share is accessible or not and sets Smb4KShare::isBroken()
+     * accordingly. Additionally, Smb4KShare::totalDiskSpace() and Smb4KShare::freeDiskSpace()
+     * are set to the current values.
+     *
+     * @param share           The share that should be checked.
+     */
+    void checkAccessibility( Smb4KShare *share );
+
     /**
      * The KProcess object.
      */
@@ -300,6 +333,11 @@ class Smb4KMounter : public QObject
      */
     QFile m_proc_mounts;
 #endif
+
+    /**
+     * This is the pointer to the private helper class.
+     */
+    Smb4KMounterPrivate *m_priv;
 };
 
 #endif
