@@ -2,8 +2,8 @@
     smb4kpasswordhandler  -  This class handles the passwords for Smb4K.
                              -------------------
     begin                : So Jan 16 2005
-    copyright            : (C) 2005 by Alexander Reinholdt
-    email                : dustpuppy@mail.berlios.de
+    copyright            : (C) 2005-2007 by Alexander Reinholdt
+    email                : dustpuppy@users.berlios.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -53,21 +53,18 @@
 #include "smb4kpasswordhandler.h"
 #include "smb4kdefs.h"
 #include "smb4kerror.h"
+#include "smb4kauthinfo.h"
+#include "smb4ksettings.h"
 
 
 #ifndef __FreeBSD__
-Smb4KPasswordHandler::Smb4KPasswordHandler( KConfig *config, Smb4KHomesSharesHandler *handler, QObject *parent, const char *name )
-: QObject( parent, name ), m_config( config ), m_handler( handler )
+Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *handler, QObject *parent, const char *name )
+: QObject( parent, name ), m_handler( handler )
 #else
-Smb4KPasswordHandler::Smb4KPasswordHandler( KConfig *config, Smb4KHomesSharesHandler *s_handler, Smb4KSambaOptionsHandler *o_handler, QObject *parent, const char *name )
-: QObject( parent, name ), m_config( config ), m_handler( s_handler ), m_options_handler( o_handler )
+Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *s_handler, Smb4KSambaOptionsHandler *o_handler, QObject *parent, const char *name )
+: QObject( parent, name ), m_handler( s_handler ), m_options_handler( o_handler )
 #endif
 {
-  if ( !m_config )
-  {
-    kdFatal() << "Smb4KPasswordHandler: No KConfig object" << endl;
-  }
-
   if ( !m_handler )
   {
     kdFatal() << "Smb4KPasswordHandler: No Smb4KHomesSharesHandler object" << endl;
@@ -84,15 +81,6 @@ Smb4KPasswordHandler::Smb4KPasswordHandler( KConfig *config, Smb4KHomesSharesHan
   m_dlg = NULL;
   m_wallet = NULL;
   m_temp_auth = NULL;
-
-  m_config->setGroup( "Authentication" );
-
-  if ( !m_config->hasKey( "Use Wallet" ) )
-  {
-    m_config->writeEntry( "Use Wallet", true );
-  }
-
-  m_config->sync();
 }
 
 
@@ -111,11 +99,9 @@ Smb4KPasswordHandler::~Smb4KPasswordHandler()
 
 void Smb4KPasswordHandler::open_close_wallet()
 {
-  m_config->setGroup( "Authentication" );
-
-  if ( m_config->readBoolEntry( "Use Wallet", true ) )
+  if ( Smb4KSettings::useWallet() )
   {
-    if ( !m_wallet || (m_wallet && !m_wallet->isOpen()) )
+    if ( !walletIsOpen() )
     {
       m_wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous );
 
@@ -124,11 +110,14 @@ void Smb4KPasswordHandler::open_close_wallet()
         if ( !m_wallet->hasFolder( "Smb4K" ) )
         {
           m_wallet->createFolder( "Smb4K" );
+          m_wallet->setFolder( "Smb4K" );
         }
+        else
+        {
+          m_wallet->setFolder( "Smb4K" );
 
-        m_wallet->setFolder( "Smb4K" );
-
-        import();
+          convert_old_entries();
+        }
       }
       else
       {
@@ -137,16 +126,14 @@ void Smb4KPasswordHandler::open_close_wallet()
         delete m_wallet;
         m_wallet = NULL;
 
-        // Do not remove the following line or the entry won't be written
-        // properly. This seems to have to do with the transition to the global
-        // config object.
-        m_config->setGroup( "Authentication" );
-        m_config->writeEntry( "Use Wallet", false );
-        m_config->sync();
-
-        import();
+        Smb4KSettings::setUseWallet( false );
+        Smb4KSettings::writeConfig();
       }
     }
+    else
+    {
+      convert_old_entries();
+    }
   }
   else
   {
@@ -159,18 +146,86 @@ void Smb4KPasswordHandler::open_close_wallet()
 }
 
 
+void Smb4KPasswordHandler::convert_old_entries()
+{
+  // Convert old entries (Smb4K 0.9.2 and earlier) to the
+  // new map based format.
+  if ( !m_wallet->entryList().isEmpty() )
+  {
+    QStringList entries = m_wallet->entryList();
+
+    // Since in the old format the keys contained a string like
+    // this: HOST:USER, we only need to test whether the first
+    // key contains a ":". If that's the case, we need to convert
+    // the entries, otherwise we don't.
+    if ( entries.first().contains( ":" ) != 0 )
+    {
+      for ( QStringList::Iterator it = entries.begin(); it != entries.end(); ++it )
+      {
+        // Get the password.
+        QString pass;
+        m_wallet->readPassword( *it, pass );
+
+        if ( (*it).startsWith( "DEFAULT:" ) )
+        {
+          // Convert the data to the new format.
+          QMap<QString,QString> map;
+          map["Login"]     = (*it).section( ":", 1, 1 );
+          map["Password"]  = pass;
+
+          m_wallet->writeMap( "DEFAULT_LOGIN", map );
+        }
+        else
+        {
+          // Convert the data to the new format.
+          QMap<QString,QString> map;
+          map["Login"]     = (*it).section( ":", 3, 3 );
+          map["Password"]  = pass;
+
+          if ( QString::compare( (*it).section( ":", 0, 0 ), "*" ) != 0 )
+          {
+            map["Workgroup"] = (*it).section( ":", 0, 0 ).upper();
+          }
+
+          if ( QString::compare( (*it).section( ":", 2, 2 ), "*" ) == 0 )
+          {
+            m_wallet->writeMap( (*it).section( ":", 1, 1 ).upper(), map );
+          }
+          else
+          {
+            m_wallet->writeMap( "//"+(*it).section( ":", 1, 1 ).upper()+
+                                "/"+(*it).section( ":", 2, 2 ).upper(), map );
+          }
+        }
+
+        // Delete the old entry.
+        m_wallet->removeEntry( *it );
+      }
+    }
+    else
+    {
+      // Do nothing.
+    }
+  }
+  else
+  {
+    // Do nothing
+  }
+}
+
+
 bool Smb4KPasswordHandler::askpass( const QString &workgroup, const QString &host, const QString &share, int desc, QWidget *parent, const char *name )
 {
+  // m_auth is NULL:
   m_auth = readAuth( new Smb4KAuthInfo( workgroup, host, share ) );
 
   // Set up the askpass dialog:
-
   m_dlg = new KDialogBase( KDialogBase::Plain, i18n( "Authentication" ), KDialogBase::Ok|KDialogBase::Cancel,
                            KDialogBase::Ok, parent, name, true, true );
 
   QFrame *frame = m_dlg->plainPage();
   QGridLayout *layout = new QGridLayout( frame );
-  layout->setSpacing( 10 );
+  layout->setSpacing( 5 );
   layout->setMargin( 0 );
 
   QLabel *pixmap_label = new QLabel( frame );
@@ -204,10 +259,14 @@ bool Smb4KPasswordHandler::askpass( const QString &workgroup, const QString &hos
       break;
   }
 
-  message.append( i18n( "Please enter authentication data for %1." ).arg(
-                  m_auth->share().stripWhiteSpace().isEmpty() ?
-                  m_auth->host() :
-                  "//"+m_auth->host()+"/"+m_auth->share() ) );
+  if ( m_auth->share().stripWhiteSpace().isEmpty() )
+  {
+    message.append( i18n( "Please enter authentication data for server %1." ).arg( m_auth->host() ) );
+  }
+  else
+  {
+    message.append( i18n( "Please enter authentication data for share %1." ).arg( "//"+m_auth->host()+"/"+m_auth->share() ) );
+  }
 
   QLabel *message_label = new QLabel( frame );
   message_label->setText( message.stripWhiteSpace() );
@@ -330,6 +389,7 @@ bool Smb4KPasswordHandler::askpass( const QString &workgroup, const QString &hos
 
 Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
 {
+  // Do nothing, if authInfo is NULL:
   if ( !authInfo )
   {
     return authInfo;
@@ -337,142 +397,226 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
 
   open_close_wallet();
 
-  m_config->setGroup( "Authentication" );
-  bool use_default = m_config->readBoolEntry( "Default Authentication" );
-
-  if ( m_wallet && m_wallet->isOpen() )
+  if ( walletIsOpen() )
   {
-    QStringList full_list = m_wallet->entryList();
-    QStringList host_list = full_list.grep( authInfo->host(), false );
+    // Get the authentication information from the wallet.
+    // Always prefer either the exact match or the information
+    // that was provided for the host.
+    QMap<QString,QString> map;
 
-    if ( !host_list.isEmpty() )
+    if ( !authInfo->share().isEmpty() )
     {
-      for ( QStringList::ConstIterator it = host_list.begin(); it != host_list.end(); ++it )
+      m_wallet->readMap( "//"+authInfo->host().upper()+"/"+authInfo->share().upper(), map );
+
+      if ( map.isEmpty() )
       {
-         if ( !authInfo->share().isEmpty() &&
-              (*it).upper().contains( ":"+authInfo->host().upper()+":"+authInfo->share().upper() ) != 0 )
+        m_wallet->readMap( authInfo->host().upper(), map );
+
+        if ( map.isEmpty() )
         {
-          QString user = (*it).section( ":", 3, 3 ).stripWhiteSpace();
-          QString pass;
+          if ( Smb4KSettings::useDefaultLogin() )
+          {
+            m_wallet->readMap( "DEFAULT_LOGIN", map );
 
-          m_wallet->readPassword( *it, pass );
-
-          authInfo->setUser( user );
-          authInfo->setPassword( pass );
-
-          break;
-        }
-        else if ( !authInfo->share().isEmpty() && (*it).upper().contains( ":"+authInfo->host().upper()+":*" ) != 0 )
-        {
-          QString user = (*it).section( ":", 3, 3 ).stripWhiteSpace();
-          QString pass;
-
-          m_wallet->readPassword( *it, pass );
-
-          authInfo->setUser( user );
-          authInfo->setPassword( pass );
-
-          continue;
-        }
-        else if ( authInfo->share().isEmpty() && (*it).upper().contains( ":"+authInfo->host().upper()+":" ) )
-        {
-          QString user = (*it).section( ":", 3, 3 ).stripWhiteSpace();
-          QString pass;
-
-          m_wallet->readPassword( *it, pass );
-
-          authInfo->setUser( user );
-          authInfo->setPassword( pass );
-
-          break;
-        }
-        else if ( authInfo->share().isEmpty() && (*it).upper().startsWith( "DEFAULT:" ) && use_default )
-        {
-          QString user = (*it).section( ":", 1, 1 ).stripWhiteSpace();
-          QString pass;
-
-          m_wallet->readPassword( *it, pass );
-
-          authInfo->setUser( user );
-          authInfo->setPassword( pass );
-
-          continue;
+            if ( map.isEmpty() )
+            {
+              return authInfo;
+            }
+            else
+            {
+              // We have authentication information.
+              // So, do nothing here.
+            }
+          }
+          else
+          {
+            return authInfo;
+          }
         }
         else
         {
-          continue;
+          // Check that the workgroup is correct.
+          if ( map.contains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
+          {
+            if ( QString::compare( map["Workgroup"].upper(), authInfo->workgroup().upper() ) != 0 )
+            {
+              return authInfo;
+            }
+            else
+            {
+              // Everything is OK. Do nothing.
+            }
+          }
+          else
+          {
+            // We cannot check if the workgroup is OK. So, just return
+            // the authentication information we just collected. If it
+            // should be wrong, the user will be asked to provide the
+            // correct data anyway.
+          }
+        }
+      }
+      else
+      {
+        // Check that the workgroup is correct.
+        if ( map.contains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
+        {
+          if ( QString::compare( map["Workgroup"].upper(), authInfo->workgroup().upper() ) != 0 )
+          {
+            return authInfo;
+          }
+          else
+          {
+            // Everything is OK. Do nothing.
+          }
+        }
+        else
+        {
+          // We cannot check if the workgroup is OK. So, just process
+          // the authentication information we just collected. If it
+          // should be wrong, the user will be asked to provide the
+          // correct data anyway.
         }
       }
     }
     else
     {
-      m_config->setGroup( "Authentication" );
+      m_wallet->readMap( authInfo->host().upper(), map );
 
-      if ( m_config->readBoolEntry( "Default Authentication", false ) )
+      if ( map.isEmpty() )
       {
-        QStringList default_list = full_list.grep( "DEFAULT", false );
-        QString user, pass;
-
-        for ( QStringList::ConstIterator it = default_list.begin(); it != default_list.end(); ++it )
+        if ( Smb4KSettings::useDefaultLogin() )
         {
-          if ( (*it).startsWith( "DEFAULT:" ) )
+          m_wallet->readMap( "DEFAULT_LOGIN", map );
+
+          if ( map.isEmpty() )
           {
-            user = (*it).section( ":", 1, 1 ).stripWhiteSpace();
-            m_wallet->readPassword( *it, pass );
-
-            authInfo->setUser( user );
-            authInfo->setPassword( pass );
-
-            break;
+            return authInfo;
           }
-          else
-          {
-            continue;
-          }
-        }
-      }
-    }
-  }
-  else
-  {
-    m_config->setGroup( "Authentication" );
-    bool remember = m_config->readBoolEntry( "Remember Passwords", true );
-
-    if ( remember && !m_auth_list.isEmpty() )
-    {
-      for ( QValueList<Smb4KAuthInfo *>::Iterator it = m_auth_list.begin(); it != m_auth_list.end(); ++it )
-      {
-        if ( (QString::compare( (*it)->workgroup().upper(), authInfo->workgroup().upper() ) == 0 &&
-              QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
-              QString::compare( (*it)->share().upper(), authInfo->share().upper() ) == 0) ||
-             (QString::compare( (*it)->workgroup().upper(), "*" ) == 0 &&
-              QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
-              QString::compare( (*it)->share().upper(), authInfo->share().upper() ) == 0) )
-        {
-          authInfo->setUser( (*it)->user() );
-          authInfo->setPassword( (*it)->password() );
-
-          break;
-        }
-        else if ( (QString::compare( (*it)->workgroup().upper(), authInfo->workgroup().upper() ) == 0 &&
-                   QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
-                   QString::compare( (*it)->share().upper(), "*" ) == 0) ||
-                  (QString::compare( (*it)->workgroup().upper(), "*" ) == 0 &&
-                   QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
-                   QString::compare( (*it)->share().upper(), "*" ) == 0) )
-        {
-          authInfo->setUser( (*it)->user() );
-          authInfo->setPassword( (*it)->password() );
-
-          continue;
         }
         else
         {
-          continue;
+          return authInfo;
+        }
+      }
+      else
+      {
+        // Check that the workgroup is correct.
+        if ( map.contains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
+        {
+          if ( QString::compare( map["Workgroup"].upper(), authInfo->workgroup().upper() ) != 0 )
+          {
+            return authInfo;
+          }
+          else
+          {
+            // Everything is OK. Do nothing.
+          }
+        }
+        else
+        {
+          // We cannot check if the workgroup is OK. So, just process
+          // the authentication information we just collected. If it
+          // should be wrong, the user will be asked to provide the
+          // correct data anyway.
         }
       }
     }
-    else if ( !remember )
+
+    // We have authentication information. Put the data into the
+    // Smb4KAuthInfo object.
+    authInfo->setUser( map["Login"] );
+    authInfo->setPassword( map["Password"] );
+  }
+  else
+  {
+    // Either the opening of the wallet failed or the user does
+    // not want to use a wallet.
+    // Let's see if we can get the authentication information from
+    // the temporary list.
+    if ( Smb4KSettings::rememberPasswords() )
+    {
+      if ( !m_auth_list.isEmpty() )
+      {
+        for ( QValueList<Smb4KAuthInfo *>::Iterator it = m_auth_list.begin(); it != m_auth_list.end(); ++it )
+        {
+          if ( !authInfo->share().isEmpty() )
+          {
+            if ( QString::compare( authInfo->host().upper(), (*it)->host().upper() ) == 0 &&
+                 QString::compare( authInfo->share().upper(), (*it)->share().upper() ) == 0 )
+            {
+              if ( QString::compare( authInfo->workgroup().upper(), (*it)->workgroup().upper() ) == 0 ||
+                   (*it)->workgroup().isEmpty() )
+              {
+                // Either the workgroup is OK, or we cannot check if it is OK.
+                // In both cases we process the data at hand.
+                authInfo->setUser( (*it)->user() );
+                authInfo->setPassword( (*it)->password() );
+
+                // Exact match. Stop here.
+                break;
+              }
+              else
+              {
+                continue;
+              }
+            }
+            else if ( QString::compare( authInfo->host().upper(), (*it)->host().upper() ) == 0 )
+            {
+              if ( QString::compare( authInfo->workgroup().upper(), (*it)->workgroup().upper() ) == 0 ||
+                   (*it)->workgroup().isEmpty() )
+              {
+                // Either the workgroup is OK, or we cannot check if it is OK.
+                // In both cases we process the data at hand.
+                authInfo->setUser( (*it)->user() );
+                authInfo->setPassword( (*it)->password() );
+
+                // Because we always prefer the exact match, we keep
+                // on searching.
+                continue;
+              }
+              else
+              {
+                continue;
+              }
+            }
+            else
+            {
+              continue;
+            }
+          }
+          else
+          {
+            if ( QString::compare( authInfo->host().upper(), (*it)->host().upper() ) == 0 )
+            {
+              if ( QString::compare( authInfo->workgroup().upper(), (*it)->workgroup().upper() ) == 0 ||
+                   (*it)->workgroup().isEmpty() )
+              {
+                // Either the workgroup is OK, or we cannot check if it is OK.
+                // In both cases we process the data at hand.
+                authInfo->setUser( (*it)->user() );
+                authInfo->setPassword( (*it)->password() );
+
+                break;
+              }
+              else
+              {
+                continue;
+              }
+            }
+            else
+            {
+              continue;
+            }
+          }
+        }
+      }
+      else
+      {
+        // Do nothing
+      }
+    }
+    else
     {
       if ( m_temp_auth )
       {
@@ -487,7 +631,7 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
 
 #ifdef __FreeBSD__
 
-  writeToSMBConfFile( auth );
+  writeToSMBConfFile( authInfo );
 
 #endif
 
@@ -495,236 +639,135 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
 }
 
 
-void Smb4KPasswordHandler::writeAuth( Smb4KAuthInfo *auth )
+void Smb4KPasswordHandler::writeAuth( Smb4KAuthInfo *authInfo )
 {
   open_close_wallet();
 
-  if ( m_wallet && m_wallet->isOpen() )
+  if ( walletIsOpen() )
   {
-    // Remove old entry:
-    QString key;
-    key.append( auth->workgroup().isEmpty() ? "*" : auth->workgroup().upper() );
-    key.append( ":" );
-    key.append( auth->host().upper() );
-    key.append( ":" );
-    key.append( auth->share().isEmpty() ? "*" : auth->share().upper() );
+    QMap<QString,QString> map;
+    map["Login"]       = authInfo->user();
+    map["Password"]    = authInfo->password();
 
-    QStringList entries = m_wallet->entryList();
-
-    for ( QStringList::ConstIterator it = entries.begin(); it != entries.end(); ++it )
+    if ( !authInfo->workgroup().isEmpty() )
     {
-      if ( (*it).stripWhiteSpace().startsWith( key ) )
-      {
-        m_wallet->removeEntry( *it );
-
-        break;
-      }
-      else
-      {
-        continue;
-      }
+      map["Workgroup"] = authInfo->workgroup().upper();
     }
 
-    key.append( ":" );
-    key.append( auth->user() );
+    if ( !authInfo->share().isEmpty() )
+    {
+      m_wallet->writeMap( "//"+authInfo->host().upper()+"/"+authInfo->share().upper(), map );
+    }
+    else
+    {
+      m_wallet->writeMap( authInfo->host().upper(), map );
+    }
 
-    m_wallet->writePassword( key, auth->password() );
     m_wallet->sync();
   }
   else
   {
-    m_config->setGroup( "Authentication" );
-
-    if ( m_config->readBoolEntry( "Remember Passwords", true ) )
+    if ( Smb4KSettings::rememberPasswords() )
     {
-      bool is_included = false;
+      Smb4KAuthInfo *tmp = NULL;
 
       for ( QValueList<Smb4KAuthInfo *>::Iterator it = m_auth_list.begin(); it != m_auth_list.end(); ++it )
       {
-        if ( (QString::compare( (*it)->workgroup().upper(), auth->workgroup().upper() ) == 0 ||
-              QString::compare( (*it)->workgroup().upper(), "*" ) == 0) &&
-             QString::compare( (*it)->host().upper(), auth->host().upper() ) == 0 &&
-             QString::compare( (*it)->share().upper(), auth->share().upper() ) == 0 )
+        if ( ((*it)->workgroup().isEmpty() ||
+             QString::compare( (*it)->workgroup().upper(), authInfo->workgroup().upper() ) == 0) &&
+             QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
+             QString::compare( (*it)->host().upper(), authInfo->share().upper() ) == 0 )
         {
-          delete *it;
-          *it = new Smb4KAuthInfo( auth->workgroup(), auth->host(), auth->share(), auth->user(), auth->password() );
-
-          is_included = true;
+          tmp = *it;
 
           break;
         }
+        else
+        {
+          continue;
+        }
       }
 
-      if ( !is_included )
+      if ( tmp )
       {
-        m_auth_list.append( new Smb4KAuthInfo( auth->workgroup(), auth->host(), auth->share(), auth->user(), auth->password() ) );
+        delete tmp;
       }
+
+      m_auth_list.append( new Smb4KAuthInfo( *authInfo ) );
     }
     else
     {
       if ( !m_temp_auth )
       {
-        m_temp_auth = new Smb4KAuthInfo( auth->workgroup(), auth->host(), auth->share(), auth->user(), auth->password() );
+        m_temp_auth = new Smb4KAuthInfo( *authInfo );
       }
     }
   }
 
 #ifdef __FreeBSD__
 
-  writeToSMBConfFile( auth );
+  writeToSMBConfFile( authInfo );
 
 #endif
 }
 
 
-Smb4KAuthInfo *Smb4KPasswordHandler::readDefaultAuth()
+Smb4KAuthInfo *Smb4KPasswordHandler::readDefaultAuth( Smb4KAuthInfo *authInfo )
 {
+  if ( !authInfo )
+  {
+    return authInfo;
+  }
+
   open_close_wallet();
 
-  Smb4KAuthInfo *auth = new Smb4KAuthInfo( QString::null, QString::null, QString::null );
-
-  if ( m_wallet && m_wallet->isOpen() )
+  if ( walletIsOpen() )
   {
-    QStringList full_list = m_wallet->entryList();
-    QStringList default_list = full_list.grep( "DEFAULT" );
+    // Read the default authentication information.
+    QMap<QString,QString> map;
 
-    QString user, pass;
+    m_wallet->readMap( "DEFAULT_LOGIN", map );
 
-    for ( QStringList::ConstIterator it = default_list.begin(); it != default_list.end(); ++it )
+    if ( !map.isEmpty() )
     {
-      if ( (*it).startsWith( "DEFAULT:" ) )
-      {
-        user = (*it).section( ":", 1, 1 ).stripWhiteSpace();
-        m_wallet->readPassword( *it, pass );
-
-        auth->setUser( user );
-        auth->setPassword( pass );
-
-        break;
-      }
-      else
-      {
-        continue;
-      }
+      authInfo->setUser( map["Login"] );
+      authInfo->setPassword( map["Password"] );
+    }
+    else
+    {
+      // Do nothing
     }
   }
   else
   {
-    delete auth;
-    auth = NULL;
+    // Nothing to do.
   }
 
-  return auth;
+  return authInfo;
 }
 
 
-void Smb4KPasswordHandler::writeDefaultAuth( Smb4KAuthInfo *auth )
+void Smb4KPasswordHandler::writeDefaultAuth( Smb4KAuthInfo *authInfo )
 {
   open_close_wallet();
 
-  if ( m_wallet && m_wallet->isOpen() )
+  if ( walletIsOpen() )
   {
-    QString key = "DEFAULT:"+auth->user();
+    QMap<QString,QString> map;
+    map["Login"]    = authInfo->user();
+    map["Password"] = authInfo->password();
 
-    m_wallet->writePassword( key, auth->password() );
+    m_wallet->writeMap( "DEFAULT_LOGIN", map );
+    m_wallet->sync();
   }
 }
 
 
-void Smb4KPasswordHandler::import()
-{
-  m_config->setGroup( "Authentication" );
-
-  int key = 0;
-
-  if ( m_config->hasKey( "Random Number" ) )
-  {
-    key = m_config->readNumEntry( "Random Number" );
-    m_config->deleteEntry( "Random Number" );
-  }
-
-  QDir::setCurrent( locateLocal( "appdata", QString::null, KGlobal::instance() ) );
-
-  QFile file( "passwords" );
-
-  if ( file.exists() && key != 0 )
-  {
-    KConfig *pw = new KConfig( "passwords", false, true, "appdata" );
-
-    if ( pw->hasGroup( "Default" ) )
-    {
-      pw->setGroup( "Default" );
-
-      QString default_user = pw->readEntry( "User" );
-      QString default_pass = pw->readEntry( "Password" );
-
-      QString dp;
-      uint index( 0 );
-
-      while ( index < default_pass.length() )
-      {
-        dp[index] = (char)( (int)default_pass[index].unicode()-key%62 );
-        index++;
-      }
-
-      if ( m_wallet && m_wallet->isOpen() )
-      {
-        m_wallet->writePassword( "DEFAULT:"+default_user, dp );
-      }
-    }
-
-    if ( pw->hasGroup( "Logins" ) )
-    {
-      pw->setGroup( "Logins" );
-
-      for ( int i = 0; ; i++ )
-      {
-        QStringList list = pw->readListEntry( QString( "%1" ).arg( i ).stripWhiteSpace(), ',' );
-
-        if ( list.isEmpty() )
-        {
-          break;
-        }
-        else
-        {
-          QString p;
-          uint index( 0 );
-
-          while( index < list[4].length() )
-          {
-            p[index] = (char)( (int)list[4][index].unicode()-key%62 );
-            index++;
-          }
-
-          QString entry = list[0].upper()+":"+list[1].upper()+":"+list[2].upper()+":"+list[3];
-
-          if ( m_wallet && m_wallet->isOpen() )
-          {
-            m_wallet->writePassword( entry, p );
-          }
-        }
-      }
-    }
-
-    if ( m_wallet && m_wallet->isOpen() )
-    {
-      m_wallet->sync();
-    }
-
-    delete pw;
-
-    file.remove();
-  }
-
-  m_config->sync();
-}
-
-
 #ifdef __FreeBSD__
 
-void Smb4KPasswordHandler::writeToSMBConfFile( Smb4KAuthInfo *auth )
+void Smb4KPasswordHandler::writeToSMBConfFile( Smb4KAuthInfo *authInfo )
 {
-  m_nsmbrc_auth = *auth;
+  m_nsmbrc_auth = *authInfo;
 
   KProcess *p = new KProcess();
   p->setUseShell( true );
@@ -751,8 +794,13 @@ void Smb4KPasswordHandler::slotGetPassword( const QString &username )
 {
   if ( m_dlg && m_auth )
   {
+    // We need to re-read the auth data here, because
+    // of the homes shares:
     Smb4KAuthInfo *auth = readAuth( new Smb4KAuthInfo( m_auth->workgroup().upper(), m_auth->host().upper(), username ) );
-    ((KLineEdit *)m_dlg->child( "AskPassPasswordEdit", "KLineEdit", true ))->setText( auth->password() );
+
+    KLineEdit *lineEdit = static_cast<KLineEdit *>(  m_dlg->child( "AskPassPasswordEdit", "KLineEdit", true ) );
+    lineEdit->setText( auth->password() );
+
     delete auth;
 
     m_auth->setShare( username );
@@ -768,11 +816,13 @@ void Smb4KPasswordHandler::slotEnableOKButton( const QString &text )
   }
 }
 
-
+#ifdef __FreeBSD__
 void Smb4KPasswordHandler::slotReceivePassword( KProcess *, char *buffer, int buflen )
 {
-#ifdef __FreeBSD__
   m_buffer.append( QString::fromLocal8Bit( buffer, buflen ) );
+#else
+void Smb4KPasswordHandler::slotReceivePassword( KProcess *, char *, int )
+{
 #endif
 }
 
