@@ -2,8 +2,8 @@
     smb4kpasswordhandler  -  This class handles the passwords for Smb4K.
                              -------------------
     begin                : So Jan 16 2005
-    copyright            : (C) 2005 by Alexander Reinholdt
-    email                : dustpuppy@mail.berlios.de
+    copyright            : (C) 2005-2007 by Alexander Reinholdt
+    email                : dustpuppy@users.berlios.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -38,14 +38,17 @@
 #include <kwallet.h>
 #include <kdialogbase.h>
 #include <kprocess.h>
-#include <kconfig.h>
+
+// forward declarations
+#ifndef __FreeBSD__
+class Smb4KAuthInfo;
+#endif
 
 // application specific includes
-#include "smb4kauthinfo.h"
 #include "smb4khomesshareshandler.h"
-
 #ifdef __FreeBSD__
 #include "smb4ksambaoptionshandler.h"
+#include "smb4kauthinfo.h"
 #endif
 
 
@@ -54,7 +57,7 @@
  * This class handles the passwords used by Smb4K to authenticate to
  * the network shares.
  *
- * @author                 Alexander Reinholdt <dustpuppy@mail.berlios.de>
+ * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
 class Smb4KPasswordHandler : public QObject
@@ -76,16 +79,13 @@ class Smb4KPasswordHandler : public QObject
      *
      * @param name          The name this class should carry.
      */
-    Smb4KPasswordHandler( KConfig *config,
-                          Smb4KHomesSharesHandler *handler,
+    Smb4KPasswordHandler( Smb4KHomesSharesHandler *handler,
                           QObject *parent = 0,
                           const char *name = 0 );
 #else
     /**
      * The constructor (FreeBSD).
      *
-     * @param config        The KConfig object that should be used
-     *
      * @param s_handler     The Smb4KHomesSharesHandler object that is needed to retrieve
      *                      infos in case we need to look up authentication information for
      *                      'homes' shares.
@@ -97,8 +97,7 @@ class Smb4KPasswordHandler : public QObject
      *
      * @param name          The name this class should carry.
      */
-    Smb4KPasswordHandler( KConfig *config,
-                          Smb4KHomesSharesHandler *s_handler,
+    Smb4KPasswordHandler( Smb4KHomesSharesHandler *s_handler,
                           Smb4KSambaOptionsHandler *o_handler,
                           QObject *parent = 0,
                           const char *name = 0 );
@@ -142,28 +141,29 @@ class Smb4KPasswordHandler : public QObject
     Smb4KAuthInfo *readAuth( Smb4KAuthInfo *authInfo );
 
     /**
-     * Writes the provided authentication data to the wallet.
+     * Write the provided authentication data to the wallet.
      *
-     * @param auth          The Smb4KAuthInfo object that holds the authentication information.
+     * @param authInfo      The Smb4KAuthInfo object that holds the authentication information.
      */
-    void writeAuth( Smb4KAuthInfo *auth );
+    void writeAuth( Smb4KAuthInfo *authInfo );
 
     /**
-     * Reads the default authentication from the wallet. This function seems only to
-     * be useful for the configuration dialog.
+     * Read the default authentication from the wallet.
+     *
+     * @param authInfo      The authentication information object.
      *
      * @returns             pointer to the authentication data object if a wallet is used or NULL otherwise
      */
-    Smb4KAuthInfo *readDefaultAuth();
+    Smb4KAuthInfo *readDefaultAuth( Smb4KAuthInfo *authInfo );
 
     /**
      * Writes the default authentication data to the wallet. This function seems only to
      * be useful for the configuration dialog.
      *
-     * @param auth          The authentication data for the default login if a wallet is
+     * @param authInfo      The authentication data for the default login if a wallet is
      *                      used or NULL otherwise.
      */
-    void writeDefaultAuth( Smb4KAuthInfo *auth );
+    void writeDefaultAuth( Smb4KAuthInfo *authInfo );
 
     /**
      * This enumeration destermines which destriptive label the askpass
@@ -171,6 +171,14 @@ class Smb4KPasswordHandler : public QObject
      */
     enum Description{ NewData, AccessDenied, BadPassword, PermDenied, AuthError, LogonFailure, None };
 
+    /**
+     * This function returns TRUE if the wallet it open at the moment and FALSE
+     * if it is closed or not used.
+     *
+     * @returns TRUE if the wallet is open.
+     */
+    bool walletIsOpen() { return (m_wallet && m_wallet->isOpen()); }
+
   protected slots:
     /**
      * Get the password for a specific share and user name.
@@ -212,6 +220,12 @@ class Smb4KPasswordHandler : public QObject
      */
     void open_close_wallet();
 
+    /**
+     * This function is used to convert old wallet entries to the new
+     * map based ones.
+     */
+    void convert_old_entries();
+
     /**
      * The KWallet object.
      */
@@ -227,12 +241,6 @@ class Smb4KPasswordHandler : public QObject
      */
     KDialogBase *m_dlg;
 
-    /**
-     * This funtion imports the authentication data from the old password file
-     * into the wallet.
-     */
-    void import();
-
     /**
      * This list holds the authentication data the user supplied if he/she
      * does not want to use KWallet.
@@ -246,11 +254,6 @@ class Smb4KPasswordHandler : public QObject
      */
     Smb4KAuthInfo *m_temp_auth;
 
-    /**
-     * The KConfig object
-     */
-    KConfig *m_config;
-
     /**
      * The Smb4KHomesSharesHandler object
      */
@@ -262,10 +265,10 @@ class Smb4KPasswordHandler : public QObject
      * FreeBSD specific: This function writes authentication information
      * to the ~/.nsmbrc file, which is used by mount_smbfs.
      *
-     * @param auth          The authentication information that should be written
+     * @param authInfo      The authentication information that should be written
      *                      to ~/.nsmbrc file.
      */
-    void writeToSMBConfFile( Smb4KAuthInfo *auth );
+    void writeToSMBConfFile( Smb4KAuthInfo *authInfo );
 
     /**
      * FreeBSD specific: Holds the authentication information that should
@@ -282,8 +285,8 @@ class Smb4KPasswordHandler : public QObject
      * The Smb4KSambaOptionsHandler object.
      */
     Smb4KSambaOptionsHandler *m_options_handler;
-#endif
 
+#endif
 };
 
 #endif
