@@ -2,8 +2,8 @@
     smb4kscanner.h  -  The network scan core class of Smb4K.
                              -------------------
     begin                : Sam Mai 31 2003
-    copyright            : (C) 2003 by Alexander Reinholdt
-    email                : dustpuppy@mail.berlios.de
+    copyright            : (C) 2003-2007 by Alexander Reinholdt
+    email                : dustpuppy@users.berlios.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -40,7 +40,12 @@
 
 // application specific includes
 #include "smb4kdefs.h"
-#include "smb4knetworkitems.h"
+
+// forward declarations
+class Smb4KScannerPrivate;
+class Smb4KWorkgroupItem;
+class Smb4KHostItem;
+class Smb4KShareItem;
 
 
 /**
@@ -145,32 +150,14 @@ class Smb4KScanner : public QObject
                   const QString &ip );
 
     /**
-     * Searches for a given host.
+     * Starts the search for a host that matches @p string. If the host is already
+     * in the list of known hosts, this function immediately emits the searchResult()
+     * signal with the Smb4KHostItem representing the host. If this is not the case,
+     * a search process is started.
+     *
+     * @param string          The user supplied search string.
      */
-    void makeSearch( const QString &host );
-
-    /**
-     * Get the preview of a share.
-     *
-     * @param workgroup       The workgroup the share is in
-     *
-     * @param host            The host where the share is located
-     *
-     * @param ip              The IP address of the host
-     *
-     * @param share           The share name
-     *
-     * @param path            The path within the share that should be displayed
-     *
-     * @returns               The name of the share. This is useful, if you want to
-     *                        preview a 'homes' share with a certain user name. If the
-     *                        the user canceled the input, QString::null will be returned.
-     */
-    const QString getPreview( const QString &workgroup,
-                              const QString &host,
-                              const QString &ip,
-                              const QString &share,
-                              const QString &path );
+    void search( const QString &string );
 
     /**
      * This function returns an Smb4KWorkgroupItem, if the the workgroup
@@ -180,12 +167,6 @@ class Smb4KScanner : public QObject
      */
     Smb4KWorkgroupItem *getWorkgroup( const QString &workgroup );
 
-    /**
-     * This function takes an Smb4KWorkgroupItem and appends it to the list, if the represented
-     * workgroup isn't already in it.
-     */
-    void appendWorkgroup( Smb4KWorkgroupItem *item );
-
     /**
      * This function reports if the scanner is running or not.
      *
@@ -208,11 +189,21 @@ class Smb4KScanner : public QObject
                             const QString &workgroup = QString::null );
 
     /**
-     * This function appends a host to the list of known servers.
+     * This function inserts a @p host into the list of known servers. If it belongs to
+     * a workgroup that was not known until now, a new Smb4KWorkgroupItem item is also
+     * created and added to the list of known workgroups. @p host is then marked as
+     * pseudo master browser. On success, the this function emits the hostAdded() and
+     * hostListChanged() signals. If the host is already in the known, nothing is done.
      *
-     * @param host          The host to add
+     * @param host          The host that should be inserted
      */
-    void addHost( Smb4KHostItem *host );
+    void insertHost( Smb4KHostItem *host );
+
+    /**
+     * This function initializes the network scan It just executes the rescan() function,
+     * so you can also use that instead.
+     */
+    void init();
 
   signals:
     /**
@@ -254,12 +245,6 @@ class Smb4KScanner : public QObject
      */
     void info( Smb4KHostItem *host );
 
-    /**
-     * This signal emits the directory list of the share that is to be
-     * previewed or 0 if an error occurred.
-     */
-    void previewResult( const QValueList<Smb4KPreviewItem *> &list );
-
     /**
      * Is emitted, when the results of a network search are to be passed.
      */
@@ -269,9 +254,9 @@ class Smb4KScanner : public QObject
      * This signal emits the host item for which an IP address has
      * been found.
      *
-     * @param item          The host item with the new IP address
+     * @param host          The host item with the new IP address
      */
-    void ipAddress( Smb4KHostItem *item );
+    void ipAddress( Smb4KHostItem *host );
 
     /**
      * This signal is emitted when the list of hosts is changed.
@@ -284,6 +269,15 @@ class Smb4KScanner : public QObject
      */
     void failed();
 
+    /**
+     * This signal is emitted when a host has been added to the list of known
+     * hosts via the addHost() function.
+     *
+     * @param host          The Smb4KHostItem that represents the host that
+     *                      was added.
+     */
+    void hostAdded( Smb4KHostItem *host );
+
   protected:
     /**
      * Starts the process.
@@ -319,11 +313,6 @@ class Smb4KScanner : public QObject
      */
     void processInfo();
 
-    /**
-     * Processes the output of the preview request.
-     */
-    void processPreview();
-
     /**
      * Processes the output of a search request.
      */
@@ -371,7 +360,7 @@ class Smb4KScanner : public QObject
     /**
      * Starts processing the queue.
      */
-    void start();
+    void slotProcessQueue();
 
     /**
      * Is called when the scan for IP addresses produced output on stdout.
@@ -396,9 +385,10 @@ class Smb4KScanner : public QObject
 
   private:
     /**
-     * Inits the network (re-)scan.
+     * Initiates the (re-)scan of the network to retrieve the initial
+     * browse list.
      */
-    void init();
+    void scanNetwork();
 
     /**
      * Scans the group master for the group members.
@@ -428,29 +418,11 @@ class Smb4KScanner : public QObject
      */
     void searchForHost( const QString &host );
 
-    /**
-     * Gets a preview of a share.
-     *
-     * @param workgroup     The workgroup of the host
-     *
-     * @param host          The name of the host
-     *
-     * @param ip            The IP address of the host
-     *
-     * @param share         The name of the remote share that should be previewed
-     *
-     * @param path          The path within the share that should be previewed
-     */
-    void preview( const QString &workgroup,
-                  const QString &host,
-                  const QString &ip,
-                  const QString &share,
-                  const QString &path );
-
     /**
      * Connect or disconnect the timer.
      *
-     * @param con           TRUE if the timer should be connected and FALSE otherwise.
+     * @param connnect      TRUE if the timer should be connected and
+     *                      FALSE otherwise.
      */
     void connect_timer( bool con );
 
@@ -459,10 +431,16 @@ class Smb4KScanner : public QObject
      */
     void lookupIPAddresses();
 
+    /**
+     * This function takes an Smb4KWorkgroupItem and appends it to the list,
+     * if the represented workgroup isn't already in it.
+     */
+    void appendWorkgroup( Smb4KWorkgroupItem *item );
+
     /**
      * Internal enumeration.
      */
-    enum TODO{ Workgroups, QueryHost, IPScan, Hosts, Shares, Info, Preview, Search, Init, Idle };
+    enum TODO{ Workgroups, QueryHost, IPScan, Hosts, Shares, Info, Search, Init, Idle };
 
     /**
      * The main KProcess object.
@@ -501,5 +479,10 @@ class Smb4KScanner : public QObject
      * the state that's emitted to notify the application about changes.
      */
     int m_state;
+
+    /**
+     * This is the pointer to the private helper class.
+     */
+    Smb4KScannerPrivate *m_priv;
 };
 #endif
