@@ -36,11 +36,13 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <fstream>
 #include <iostream>
 using namespace std;
 
-#define SMB4K_CAT_VERSION 0.5
+#define MAX_LINE_LENGTH   1024
+#define SMB4K_CAT_VERSION  "0.7"
 
 void info()
 {
@@ -128,7 +130,7 @@ int main( int argc, char *argv[] )
 			}
 			case '?':
 			{
-				// Abort the program if an unknown option 
+				// Abort the program if an unknown option
 				// is encountered:
 				exit( EXIT_FAILURE );
 			}
@@ -182,14 +184,15 @@ int main( int argc, char *argv[] )
 			exit( EXIT_FAILURE );
 		}
 
-		char line[255];
+		char line[MAX_LINE_LENGTH];
 		line[0] = '\0';
 
-		while( !feof( fd ) )
+		while ( !feof( fd ) )
 		{
-			fgets( line, 255, fd );
-			cout << line;
-			line[0] = '\0';
+			if ( fgets( line, MAX_LINE_LENGTH, fd ) )
+			{
+				cout << line;
+			}
 		}
 
 		fclose( fd );
